@@ -73,9 +73,8 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self._timeout = 10000
         self._catalog_api_base = f"{url}{catalog_api_path}"
         self._pipeline_api_base = f"{url}{pipeline_api_path}"
-        is_ends_with_torch = url.endswith('/torch')
         loc = url.rfind('/torch')
-        if is_ends_with_torch:
+        if loc > 0:
             self._admin_api_base = f"{url[:loc]}{admin_api_path}"
         else:
             self._admin_api_base = f"{url}{admin_api_path}"
